# oYou
Build low level tensorflow model with pleasure and flexibility

## Why?
Low level tensorflow api is powerful and flexible, but lacks code reuse.
High level tensorflow api is simple and elegant, but lacks flexibility.

oYou balance benefits and deficits of the high level and low level frameworks.
Using oYou


## Get started with oYou

### install
```terminal
pip install oyou
```

### import
```python
import oyou
```

